## 自己手写的 logger
>不喜勿喷
---
## Getting Started:
```bash
pip install msdnicrosoft_logger
```

## Example:
```python
import msdnicrosoft_logger
logger = msdnicrosoft_logger.Log(Shell=True,LogFile=True,FileName="%Y-%m-%d_%H-%M.log")
# ... Enter your code there
```

